@@ -5,5 +5,5 @@ __author__ = 'J Enoch Jones'
 __docs__ = ''
 __doi__ = ''
 __license__ = 'MIT License'
-__source_code__ = ''
-__version__ = '0.0.7'
+__source_code__ = 'https://github.com/jenochjones/ncarrays'
+__version__ = '0.0.8'
